# aiolambda [![Build Status](https://travis-ci.org/pando85/aiolambda.svg?branch=master)](https://travis-ci.org/pando85/aiolambda) [![License](https://img.shields.io/github/license/pando85/aiolambda.svg)](https://github.com/pando85/aiolambda/blob/master/LICENSE)
Python async microservices fasts!
